@@ -1,6 +1,6 @@
 package WWW::EZTV;
 {
-  $WWW::EZTV::VERSION = '0.02';
+  $WWW::EZTV::VERSION = '0.03';
 }
 use Moose;
 with 'WWW::EZTV::UA';
@@ -53,24 +53,28 @@ WWW::EZTV - EZTV scrapper
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
-First create a WWW::EZTV object to navigate.
-
     use WWW::EZTV;
+    use v5.10;
 
     my $eztv = WWW::EZTV->new;
 
+    # Find one show
     my $show = $eztv->find_show(sub{ $_->name =~ /Walking dead/i });
 
+    # Find one episode
     my $episode = $show->find_episode(sub{ 
         $_->season == 3 && 
         $_->number == 8 && 
         $_->quality eq 'standard' 
     });
 
+    # Get first torrent url for this episode
+    say $episode->find_link(sub{ $_->type eq 'torrent' })->url;
+
 =head1 ATTRIBUTES
 
 =head2 url
